@@ -101,9 +101,11 @@ void SLPDDatabaseAge(int seconds, int ageall)
 
             if ( srvreg->urlentry.lifetime == SLP_LIFETIME_MAXIMUM )
             {
-                if ( srvreg->source == SLP_REG_SOURCE_LOCAL )
+                if ( srvreg->source == SLP_REG_SOURCE_LOCAL ||
+                     srvreg->source == SLP_REG_SOURCE_STATIC )
                 {
                     /* entries that were made from local registrations    */
+                    /* and entries made from static registration file     */
                     /* that have a lifetime of SLP_LIFETIME_MAXIMUM must  */
                     /* NEVER be aged                                      */
                     continue;
@@ -117,6 +119,7 @@ void SLPDDatabaseAge(int seconds, int ageall)
                 }
             }
 
+            /* Age entry */
             srvreg->urlentry.lifetime -= seconds;
 
             /* Remove entries that have timed out */
