@@ -488,12 +488,13 @@ void WINAPI SLPDServiceMain(DWORD argc, LPTSTR *argv)
 
 
 /*--------------------------------------------------------------------------*/
-void SLPDCmdInstallService() 
+void SLPDCmdInstallService(int automatic) 
 /*--------------------------------------------------------------------------*/
 {
     SC_HANDLE   schService; 
     SC_HANDLE   schSCManager; 
 
+    DWORD start_type;
     TCHAR szPath[512]; 
 
     if(GetModuleFileName( NULL, szPath, 512 ) == 0)
@@ -504,6 +505,15 @@ void SLPDCmdInstallService()
         return; 
     }
 
+    if(automatic)
+    {
+      start_type = SERVICE_AUTO_START;
+    }
+    else
+    {
+      start_type = SERVICE_DEMAND_START;
+    } 
+
     schSCManager = OpenSCManager(
                                 NULL,                   /* machine (NULL == local)    */
                                 NULL,                   /* database (NULL == default)    */
@@ -517,7 +527,7 @@ void SLPDCmdInstallService()
                                   G_SERVICEDISPLAYNAME, /* name to display    */
                                   SERVICE_ALL_ACCESS,         /* desired access    */
                                   SERVICE_WIN32_OWN_PROCESS,  /* service type    */
-                                  SERVICE_DEMAND_START,       /* start type    */
+                                  start_type,       			  /* start type    */
                                   SERVICE_ERROR_NORMAL,       /* error control type    */
                                   szPath,                     /* service's binary    */
                                   NULL,                       /* no load ordering group    */
@@ -542,13 +552,38 @@ void SLPDCmdInstallService()
         printf("OpenSCManager failed - %s\n", GetLastErrorText(szErr,256)); 
 } 
 
-
+static void SLPDHlpStopService(SC_HANDLE schService)
+{
+	/* try to stop the service    */
+	if(ControlService(schService, SERVICE_CONTROL_STOP, &ssStatus))
+	{
+		printf("Stopping %s.", G_SERVICEDISPLAYNAME);
+		Sleep(1000);
+      
+		while(QueryServiceStatus(schService, &ssStatus))
+		{
+			if(ssStatus.dwCurrentState == SERVICE_STOP_PENDING)
+			{
+				printf(".");
+				Sleep(1000);
+			}
+			else
+				break; 
+		} 
+      
+		if(ssStatus.dwCurrentState == SERVICE_STOPPED)
+			printf("\n%s stopped.\n", G_SERVICEDISPLAYNAME);
+		else
+			printf("\n%s failed to stop.\n", G_SERVICEDISPLAYNAME); 
+	}
+}
+ 
 /*--------------------------------------------------------------------------*/
 void SLPDCmdRemoveService() 
 /*--------------------------------------------------------------------------*/
 {
-    SC_HANDLE   schService; 
-    SC_HANDLE   schSCManager; 
+    SC_HANDLE schService; 
+    SC_HANDLE schSCManager; 
 
     schSCManager = OpenSCManager(
                                 NULL,                   /* machine (NULL == local)    */
@@ -560,31 +595,9 @@ void SLPDCmdRemoveService()
 
         if(schService)
         {
-            /* try to stop the service    */
-            if(ControlService( schService, SERVICE_CONTROL_STOP, &ssStatus ))
-            {
-                printf("Stopping %s.", G_SERVICEDISPLAYNAME); 
-                Sleep( 1000 ); 
+				SLPDHlpStopService(schService);
 
-                while(QueryServiceStatus( schService, &ssStatus ))
-                {
-                    if(ssStatus.dwCurrentState == SERVICE_STOP_PENDING)
-                    {
-                        printf("."); 
-                        Sleep( 1000 ); 
-                    }
-                    else
-                        break; 
-                } 
-
-                if(ssStatus.dwCurrentState == SERVICE_STOPPED)
-                    printf("\n%s stopped.\n", G_SERVICEDISPLAYNAME );
-                else
-                    printf("\n%s failed to stop.\n", G_SERVICEDISPLAYNAME ); 
-
-            }
-
-            /* now remove the service    */
+				/* now remove the service    */
             if(DeleteService(schService))
                 printf("%s removed.\n", G_SERVICEDISPLAYNAME );
             else
@@ -602,12 +615,77 @@ void SLPDCmdRemoveService()
         printf("OpenSCManager failed - %s\n", GetLastErrorText(szErr,256)); 
 } 
 
+/*--------------------------------------------------------------------------*/
+void SLPDCmdStartService()
+/*--------------------------------------------------------------------------*/
+{
+	 SC_HANDLE schService; 
+	 SC_HANDLE schSCManager; 
+
+	 schSCManager = OpenSCManager(
+	 									  NULL,                   /* machine (NULL == local)    */
+	 									  NULL,                   /* database (NULL == default) */
+	 									  SC_MANAGER_ALL_ACCESS); /* access required    		  */
+	 if(schSCManager)
+	 {
+	 	  schService = OpenService(schSCManager, G_SERVICENAME, SERVICE_ALL_ACCESS); 
+
+	 	  if(schService)
+	 	  {
+	 			if( !StartService(schService, 0, NULL))
+	 			{
+	 				 printf("OpenService failed - %s\n", GetLastErrorText(szErr,256)); 
+	 			}
+	 			CloseServiceHandle(schService); 
+	 	  }
+	 	  else
+	 	  {
+	 	  		printf("OpenService failed - %s\n", GetLastErrorText(szErr,256)); 
+	 	  }
+	 	  CloseServiceHandle(schSCManager); 
+	 }
+	 else
+	 {
+	 	  printf("OpenSCManager failed - %s\n", GetLastErrorText(szErr,256)); 
+	 }
+}
+
+/*--------------------------------------------------------------------------*/
+void SLPDCmdStopService()
+/*--------------------------------------------------------------------------*/
+{
+	 SC_HANDLE schService; 
+	 SC_HANDLE schSCManager; 
+
+	 schSCManager = OpenSCManager(
+	 									  NULL,                   /* machine (NULL == local)    */
+	 									  NULL,                   /* database (NULL == default) */
+	 									  SC_MANAGER_ALL_ACCESS); /* access required    		  */
+	 if(schSCManager)
+	 {
+	 	  schService = OpenService(schSCManager, G_SERVICENAME, SERVICE_ALL_ACCESS); 
+
+	 	  if(schService)
+	 	  {
+	 			SLPDHlpStopService(schService);
+	 			CloseServiceHandle(schService); 
+	 	  }
+	 	  else
+	 	  {
+	 			printf("OpenService failed - %s\n", GetLastErrorText(szErr,256)); 
+	 	  }
+	 	  CloseServiceHandle(schSCManager); 
+	 }
+	 else
+	 {
+	 	  printf("OpenSCManager failed - %s\n", GetLastErrorText(szErr,256)); 
+	 }
+}
 
 /*--------------------------------------------------------------------------*/
 void SLPDCmdDebugService(int argc, char ** argv) 
 /*--------------------------------------------------------------------------*/
 {
-
     printf("Debugging %s.\n", G_SERVICEDISPLAYNAME); 
 
     SetConsoleCtrlHandler( ControlHandler, TRUE ); 
@@ -638,11 +716,17 @@ void __cdecl main(int argc, char **argv)
         SLPDCmdDebugService(argc, argv);
         break;
     case SLPD_INSTALL:
-        SLPDCmdInstallService();
+        SLPDCmdInstallService(G_SlpdCommandLine.autostart);
         break;
     case SLPD_REMOVE:
         SLPDCmdRemoveService();
         break;
+    case SLPD_START:
+        SLPDCmdStartService();
+		  break;
+    case SLPD_STOP:
+        SLPDCmdStopService();
+        break;
     default:
         SLPDPrintUsage();
         StartServiceCtrlDispatcher(dispatchTable);
