@@ -82,11 +82,13 @@ typedef SOCKET              sockfd_t;
 
 /* enum detailing what to do with SLPD when launching it :
    run in the console for debug, install it as a service or uninstall it */
-typedef enum _SLPDAction
+typedef enum SLPDAction
 {
     SLPD_DEBUG   = 0,
-    SLPD_INSTALL = 1,
-    SLPD_REMOVE  = 2
+    SLPD_INSTALL	= 1,
+    SLPD_REMOVE 	= 2,
+    SLPD_START 	= 3,
+    SLPD_STOP		= 4
 } SLPDAction;
 
 
@@ -111,9 +113,11 @@ VOID WINAPI SLPDServiceMain(DWORD argc, LPTSTR *argv);
 
 
 /*=========================================================================*/
-VOID SLPDCmdInstallService(); 
+VOID SLPDCmdInstallService(int automatic); 
 /* Installs the SLPD service in the system                                 */
 /*                                                                         */
+/* automatic boolean specifying whether service should start automatically */
+/*                                                                         */
 /* returns  none                                                           */
 /*=========================================================================*/
 
